output

package
v1.9.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 23, 2025 License: Apache-2.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsFileExist

func IsFileExist(path string) bool

IsFileExist checks whether a file exists at the given path.

Types

type Options

type Options struct {
	PrintInputs    bool
	Subtests       bool
	Parallel       bool
	Named          bool
	UseGoCmp       bool
	Template       string
	TemplateDir    string
	TemplateParams map[string]interface{}
	TemplateData   [][]byte
	UseAI          bool
	AIModel        string
	AIEndpoint     string
	AIMinCases     int
	AIMaxCases     int
	// contains filtered or unexported fields
}

Options contains configuration for generating and formatting test output.

func (*Options) Process added in v1.7.0

func (o *Options) Process(head *models.Header, funcs []*models.Function) ([]byte, error)

Process generates formatted test code from the header and function signatures.

Jump to