Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsFileExist ¶
IsFileExist checks whether a file exists at the given path.
Types ¶
type Options ¶
type Options struct {
PrintInputs bool
Subtests bool
Parallel bool
Named bool
UseGoCmp bool
Template string
TemplateDir string
TemplateParams map[string]interface{}
TemplateData [][]byte
UseAI bool
AIModel string
AIEndpoint string
AIMinCases int
AIMaxCases int
// contains filtered or unexported fields
}
Options contains configuration for generating and formatting test output.
Click to show internal directories.
Click to hide internal directories.